function [U,dataDWT,N,data0,pdata] = pdata_nD(data,sw,dsw)

%% function [U,dataDWT,N,data0,pdata] = pdata_nD(data,sw,dsw)
%
% Preprocessing function, handle single and sets of time-series (1D, 2D or
% 3D) plus single and sets of images (1D or 2D)
%
% The function pdata_nD(data,sw,dsw) cuts and stacks the 'data' according to the
% analysis window of size sw (sw = [n1] for time-series and sw = [n1 n2]
% for images) and with overlap parameter dsw (ether [dn1] or [dn1 dn2]).
% 
% INPUTS
% - data    :   the data vector / matrix / cube 
% - sw      :   analysis window (sw = [n1] for time-series and sw = [n1 n2] for images)
% - dsw     :   analysis window overlap parameter (either [dn1] or [dn1 dn2]).
%
% OUTPUTS
% - U       :   structure with entries
%       U.u       :   a vector containing the dimensions of the set under analysis after cutting
%       U.dim     :   the dimensionality of the set under analysis
% - dataDWT :   the analyzed time series / image patches stacked in a matrix [Dim_Analyze X N_elements]
% - N       :   the size of each individual data component
% - data0   :   the original data with border effects removed
% - pdata   :   the analyzed time series / image patches stored as individual elements in a structure
%
% --------------------------------------------------------------------------------
% --------------------------------------------------------------------------------
% Examples
% --------------------------------------------------------------------------------
% 1) Time-series
% --------------------------------------------------------------------------------
% data = randn(10,20,310); % 3-D, corresponding to a dataset of time-series of length 310 organized on a 2D grid (10x20)
% [u,pdata,data0,dataDWT,N] = pdata_nD(data,40,20); %Setting to cut the dataset into half-overlapping time-series of length 40
% pdata; % 4-D of dimensions 10x20x14x40 corresponding to time-series of length
% % 40 organized on 3-D grid (10x20x14);
% u; % [10 20 14], dimension of the 3-D grid (here, 14 = floor((310-(40-20))/20))
% data0; % 3-D of dimensions 10x20x300 corresponding to the actual dataset under analysis after border effect
% dataDWT; % 2-D of dimension 2800 (prod(u)) x 40 stacking all time-series
% N; % Actual length of the time-series to be proceeded, here 40.
% --------------------------------------------------------------------------------
% 2) Image
% data = randn(50,50,10); % 3-D, corresponding to sequence of 10 images of dimensions 50x50
% [u,pdata,data0,dataDWT,N] = pdata_nD(data,[10 50],[5 0]); % Setting to
% % cut the dataset into patches of dimension 10x50 with 50% overlappin along the x-dimension and 0% overlapping along y-dimension
% 


dimw = length(sw);

switch dimw
    case 1 % Time series
        [data0,pdata,u] = pcrope_1D(data,sw,dsw);
        sz = size(pdata); N = sz(end);
        dataDWT = reshape(pdata,[],N);
    case 2 % Images
        [data0,pdata,dataDWT,u] = pcrope_2D(data,sw,dsw);
        sz = size(dataDWT(:,:,1));N = sz(1:2);
end

U.u=u; U.dim=numel(u); U.N=N;

end