function [ec2,Tc2,ec20,Tc20,ec1,Tc1,ec10,Tc10,epc1,Tepc1] = est_bayes_mvmfa(lxft,param_model,REGU,tag)
%
% function [ec2,Tc2,ec20,Tc20,ec1,Tc1,ec10,Tc10,epc1,Tepc1] = est_bayes_mvmfa(lxft,param_model,REGU,tag)
%
% MCMC algorithms for MMSE estimation of the multifractal parameters c2 and c1
%     if the number of requested outputs is less than 5, e.g. [ec2,Tc2], only c2 is estimated
%     otherwise, (c2,c1) are estimated jointly
%
% INPUT
% - lxft        :   matrix with DFT coefficients of log-wavelet leaders of data components, stacked as vectors
%                   computed by "preproc_data_mvmfa.m"
% - param_model :   structure with Bayesian model parameters produced by "init_model_mvmfa.m"
% - REGU        :   type of regularization for c2 (REGU(1)) and c1 (REGU(1)) (default: [0 0])
%           currently implemented options:
%               [0 0] no regularization for c2 and c1
%               [1 0] GMRF prior for c2, no regularization for c1 (if c1 is computed)
%               [1 1] GMRF prior for c2, SAR prior forc1 (if c1 is computed)
% - tag         :   isotropic ('3D') or anisotropic ('2D+1D') spatial regularization
%                   DEFAULT: '3D' for time series, '2D+1D' for images
%                   for 3D data collections only 
%
% NOTE: if param_model.EST.MEMSAVE = 0, the MCMC chains, Tc1, Tc2,..., are not stored and an empty array is output in place
%
% HW, BCN, 03/2017

if nargin < 4 | isempty(tag); 
    if numel(param_model.N)==2; tag = '2D+1D'; else; tag = '3D'; end
end
if nargin < 3; REGU = [0 0]; end
ec2=[];Tc2=[];ec20=[];Tc20=[];ec1=[];Tc1=[];ec10=[];Tc10=[];epc1=[];Tepc1=[];

% check what is to do
if nargout<5; doc1=0;  else doc1=1; end


if doc1 % Joint estimation of (c1,c2)
    if REGU(1)==0&REGU(2)==0;
        % Non informative priors
        [ec2,Tc2,ec20,Tc20,ec1,Tc1,ec10,Tc10] = pc2BayesDA(lxft,param_model);
    elseif REGU(1)==1&REGU(2)==1;
        % Informative priors: GMRF(c2) and SAR(c1)
        [ec2,Tc2,ec20,Tc20,ec1,Tc1,ec10,Tc10,epc1,Tepc1] = pnD_c2GMRF_c1SAR(lxft,param_model,tag);
    elseif REGU(1)==1&REGU(2)==0;
        % Informative prior GMRF(c2) and Non informative prior for c1
    	[ec2,Tc2,ec20,Tc20,ec1,Tc1,ec10] = pnD_c2GMRF(lxft,param_model,tag);
    else
        disp('This regularization combination for c2 and c1 is not implemented.');
    end
else % Only estimation of c2
    if REGU(1)==0;
        % Non informative priors
        [ec2,Tc2,ec20,Tc20] = pc2BayesDA(lxft,param_model);
    elseif REGU(1)==1;
        % Informative prior: GMRF
        [ec2,Tc2,ec20,Tc20] = pnD_c2GMRF(lxft,param_model,tag);  
    else
        disp('This regularization for c2 is not implemented.');
    end
end
