function [lxft,param_data,data0,pdata] = preproc_data_mvmfa(data,sw,dsw,j1,j2,Nwt,gamint)
%
% function [y,param_data,data0,pdata] = preproc_data_mvmfa(data,sw,dsw,j1,j2,Nwt,gamint)
%
% Function for preprocessing N-D data for est_bayes_mvmfa.
%
% Handles single and sets of time-series (1D, 2D or 3D) as well as single and sets of images (1D or 2D)
%
% It cuts and stacks the 'data' according to the analysis window 
% of size sw (sw = [n1] for time-series and sw = [n1 n2] for images) 
% and with overlap parameter dsw (either [dn1] or [dn1 dn2]).
% 
% It then computes the DFT of log-leaders with analysis parameters (j1,j2,Nwt,gamint)
%
%
% INPUTS
% - data    :   the data vector / matrix / cube 
% - sw      :   analysis window (sw = [n1] for time-series and sw = [n1 n2] for images)
% - dsw     :   analysis window overlap parameter (either [dn1] or [dn1 dn2]).
% - j1      :   finest scale for estimation
% - j2      :   coarsest scale for estimation
% - Nwt     :   wavelet vanishing moment (Daubechies)
% - gamint  :   fractional integration parameter for computing wavelet leaders
%
% OUTPUTS
% - lxft    :   matrix with DFT coefficients of log-wavelet leaders of data components, stacked as vectors
% - param_data: structure with all relevant analysis parameters as entries (given as input), as well as:
%     - u       :   a vector containing the dimensions of the set under analysis after cutting
%     - dim     :   the dimensionality of the set under analysis
%     - N       :   the size of each individual data component
%     - Nj      :   number of coefficients per scale
%     - V       :   variance of log-leaders per scale for each component (for linear regression based estimation of c2)
%     - mV      :   mean of log-leaders per scale for each component (for linear regression based estimation of c1)
% 
% optional OUTPUTS (not needed by est_bayes_mvmfa)
% - data0   :   the original data with border effects removed
% - pdata   :   the analyzed time series / image patches stored as individual elements in a structure
%
% HW, BCN, 03/2017

[U,dataDWT,N,data0,pdata] = pdata_nD(data,sw,dsw); % Data cutting according to parameters
[lxft,Ni,Nj,w,ind,V,mV] = pDWT_nDNZ(dataDWT,j1,j2,N,Nwt,gamint); % Computation of DWT and DFT

% write parameters
param_data.sw=sw;
param_data.dsw=dsw;
param_data.j1=j1;
param_data.j2=j2;
param_data.Nwt=Nwt;
param_data.gamint=gamint;
param_data.dim=U.dim;
param_data.u=U.u;
param_data.N=N;
param_data.Ni=Ni;
param_data.Nj=Nj;
param_data.V=V;
param_data.mV=mV;

